@@ -3,9 +3,13 @@
 
 __author__ = 'zeus'
 
-from django.conf.urls.defaults import *
+try:
+    from django.conf.urls import patterns, url, include
+except ImportError:
+    from django.conf.urls.defaults import patterns, url, include
+
 from imagestore.views import AlbumListView
 
 urlpatterns = patterns('',
     url(r'^', include('imagestore.urls', namespace='imagestore')),
-    )
\ No newline at end of file
+    )
