@@ -2,7 +2,8 @@
 # vim:fileencoding=utf-8
 
 __author__ = 'zeus'
-from imagestore.utils import load_class, get_model_string
+
+from imagestore.utils import load_class
 from django.conf import settings
 
 Album = load_class(getattr(settings, 'IMAGESTORE_ALBUM_MODEL', 'imagestore.models.album.Album'))
@@ -16,4 +17,4 @@ album_applabel = Album._meta.app_label
 album_classname = Album.__name__.lower()
 
 
-from upload import AlbumUpload
\ No newline at end of file
+from .upload import AlbumUpload
