@@ -3,9 +3,9 @@
 
 __author__ = 'zeus'
 
-from bases.album import BaseAlbum
+from .bases.album import BaseAlbum
 from django.utils.translation import ugettext_lazy as _
-from imagestore.utils import load_class, get_model_string
+
 
 class Album(BaseAlbum):
 
