@@ -3,7 +3,7 @@
 
 __author__ = 'zeus'
 
-from bases.image import BaseImage
+from .bases.image import BaseImage
 from django.utils.translation import ugettext_lazy as _
 from imagestore.utils import load_class, get_model_string
 
