@@ -14,7 +14,7 @@ from django.utils.translation import ugettext_lazy as _
 from django.views.generic import ListView, DetailView, CreateView, UpdateView, DeleteView
 from tagging.models import TaggedItem
 from tagging.utils import get_tag
-from utils import load_class
+from .utils import load_class
 from django.db.models import Q
 
 try:
@@ -253,4 +253,4 @@ class DeleteImage(DeleteView):
     @method_decorator(login_required)
     @method_decorator(permission_required('%s.delete_%s' % (image_applabel, image_classname)))
     def dispatch(self, *args, **kwargs):
-        return super(DeleteImage, self).dispatch(*args, **kwargs)
\ No newline at end of file
+        return super(DeleteImage, self).dispatch(*args, **kwargs)
